@@ -21,6 +21,8 @@
 #include "elisaapplication.h"
 #include "elisa_settings.h"
 
+#include "localFileConfiguration/elisaconfigurationdialog.h"
+
 //#define QT_QML_DEBUG
 
 #if defined KF5Declarative_FOUND && KF5Declarative_FOUND
@@ -41,22 +43,17 @@
 #include <KDBusService>
 #endif
 
-#include <QSortFilterProxyModel>
 
 #include <QIcon>
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QtGlobal>
 #include <QStandardPaths>
 
 #include <QQmlApplicationEngine>
-#include <QQmlEngine>
 #include <QQmlFileSelector>
-#include <QQmlDebuggingEnabler>
-#include <QQmlContext>
 #include <QQuickStyle>
-#include <QScreen>
+#include <QQmlContext>
 
 #if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
 #include <QAndroidService>
@@ -119,23 +116,23 @@ int main(int argc, char *argv[])
     KAboutData aboutData( QStringLiteral("elisa"),
                           i18n("Elisa"),
                           QStringLiteral(ELISA_VERSION_STRING),
-                          i18n("A Simple Music Player written with KDE Frameworks"),
+                          i18n("A Simple Music Player made with love by the KDE community"),
                           KAboutLicense::LGPL_V3,
-                          i18n("(c) 2015-2019, Elisa contributors"));
+                          i18n("(c) 2015-2020, Elisa contributors"));
 
     aboutData.addAuthor(QStringLiteral("Matthieu Gallien"),i18n("Creator"), QStringLiteral("mgallien@mgallien.fr"));
     aboutData.addAuthor(QStringLiteral("Alexander Stippich"), i18n("Author"), QStringLiteral("a.stippich@gmx.net"));
+    aboutData.addAuthor(QStringLiteral("Nate Graham"), i18n("Author"), QStringLiteral("nate@kde.org"));
 
     aboutData.addCredit(QStringLiteral("Andrew Lake"), i18n("Concept and design work"), QStringLiteral("jamboarder@gmail.com"));
     aboutData.addCredit(QStringLiteral("Luigi Toscano"), i18n("Localization support"), QStringLiteral("luigi.toscano@tiscali.it"));
     aboutData.addCredit(QStringLiteral("Safa Alfulaij"), i18n("Right to left support in interface"), QStringLiteral("safa1996alfulaij@gmail.com"));
     aboutData.addCredit(QStringLiteral("Diego Gangl"), i18n("Various improvements to the interface"), QStringLiteral("diego@sinestesia.co"));
+    aboutData.addCredit(QStringLiteral("Jérôme Guidon"), i18n("Support for online radios"), QStringLiteral("guidon@live.fr"));
 
     KAboutData::setApplicationData(aboutData);
 
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
@@ -162,6 +159,8 @@ int main(int argc, char *argv[])
 
     std::unique_ptr<ElisaApplication> myApp = std::make_unique<ElisaApplication>();
 
+    myApp->setQmlEngine(&engine);
+
 #if defined KF5DBusAddons_FOUND && KF5DBusAddons_FOUND
     QObject::connect(&elisaService, &KDBusService::activateActionRequested, myApp.get(), &ElisaApplication::activateActionRequested);
     QObject::connect(&elisaService, &KDBusService::activateRequested, myApp.get(), &ElisaApplication::activateRequested);
@@ -171,13 +170,14 @@ int main(int argc, char *argv[])
     auto arguments = ElisaUtils::EntryDataList{};
     auto realArgumentsList = parser.positionalArguments();
 
-    for (auto oneArgument : realArgumentsList) {
+    for (const auto &oneArgument : realArgumentsList) {
         arguments.push_back(ElisaUtils::EntryData{{}, {}, QUrl(oneArgument)});
     }
 
     myApp->setArguments(arguments);
 
     engine.rootContext()->setContextProperty(QStringLiteral("elisa"), myApp.release());
+    engine.rootContext()->setContextProperty(QStringLiteral("config"), new ElisaConfigurationDialog);
 
     engine.load(QUrl(QStringLiteral("qrc:/qml/ElisaMainWindow.qml")));
 
