@@ -19,11 +19,9 @@
 #define MANAGEMEDIAPLAYERCONTROL_H
 
 #include "elisaLib_export.h"
-
+#include <QPersistentModelIndex>
 #include <QObject>
-#include <QModelIndex>
 
-class QAbstractItemModel;
 
 class ELISALIB_EXPORT ManageMediaPlayerControl : public QObject
 {
@@ -115,12 +113,6 @@ private:
 
     QPersistentModelIndex mNextTrack;
 
-    bool mCurrentTrackWillBeRemoved = false;
-
-    bool mSkipBackwardControlWasEnabled = false;
-
-    bool mSkipForwardControlWasEnabled = false;
-
     bool mIsInPlayingState = false;
 
 };
