@@ -21,7 +21,7 @@
 
 #include <KI18n/KLocalizedString>
 
-#include <QtConcurrentRun>
+#include <QtConcurrent>
 
 TrackMetadataModel::TrackMetadataModel(QObject *parent)
     : QAbstractListModel(parent)
@@ -165,8 +165,10 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::ResourceRole:
             result = i18nc("Radio HTTP address for radio metadata view", "Stream Http Address");
             break;
-        case DataTypes::SecondaryTextRole:
         case DataTypes::ImageUrlRole:
+            result = i18nc("Image address for radio metadata view", "Image Address");
+            break;
+        case DataTypes::SecondaryTextRole:
         case DataTypes::ShadowForImageRole:
         case DataTypes::ChildModelRole:
         case DataTypes::StringDurationRole:
@@ -185,6 +187,7 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::FirstPlayDate:
         case DataTypes::PlayFrequency:
         case DataTypes::ElementTypeRole:
+        case DataTypes::FullDataRole:
             break;
         }
         break;
@@ -195,7 +198,8 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
             result = TextEntry;
             break;
         case DataTypes::ResourceRole:
-            result = TextEntry;
+        case DataTypes::ImageUrlRole:
+            result = UrlEntry;
             break;
         case DataTypes::ArtistRole:
             result = TextEntry;
@@ -244,7 +248,6 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::BitRateRole:
         case DataTypes::ChannelsRole:
         case DataTypes::SecondaryTextRole:
-        case DataTypes::ImageUrlRole:
         case DataTypes::ShadowForImageRole:
         case DataTypes::ChildModelRole:
         case DataTypes::StringDurationRole:
@@ -263,6 +266,7 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::FirstPlayDate:
         case DataTypes::PlayFrequency:
         case DataTypes::ElementTypeRole:
+        case DataTypes::FullDataRole:
             break;
         }
         break;
@@ -274,9 +278,12 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
 bool TrackMetadataModel::setData(const QModelIndex &index, const QVariant &value, int role)
 {
     if (data(index, role) != value) {
-        mTrackData[mTrackKeys[index.row()]] = value;
+        auto dataType = mTrackKeys[index.row()];
 
-        emit dataChanged(index, index, QVector<int>() << role);
+        mTrackData[dataType] = value;
+        mFullData[dataType] = value;
+
+        Q_EMIT dataChanged(index, index, QVector<int>() << role);
         return true;
     }
     return false;
@@ -348,12 +355,6 @@ void TrackMetadataModel::fillDataFromTrackData(const TrackMetadataModel::TrackDa
 
     for (DataTypes::ColumnsRoles role : fieldsForTrack) {
         if (trackData.constFind(role) != trackData.constEnd()) {
-            if (role == DataTypes::RatingRole) {
-                if (trackData[role].toInt() == 0) {
-                    continue;
-                }
-            }
-
             mTrackKeys.push_back(role);
             mTrackData[role] = trackData[role];
         }
@@ -407,6 +408,11 @@ void TrackMetadataModel::fillLyricsDataFromTrack()
     endInsertRows();
 }
 
+const TrackMetadataModel::TrackDataType &TrackMetadataModel::allTrackData() const
+{
+    return mTrackData;
+}
+
 void TrackMetadataModel::lyricsValueIsReady()
 {
     if (!mLyricsValueWatcher.result().isEmpty()) {
@@ -437,10 +443,6 @@ void TrackMetadataModel::initialize(MusicListenersManager *newManager, DatabaseI
 
     if (mManager) {
         mDataLoader.setDatabase(mManager->viewDatabase());
-        connect(this, &TrackMetadataModel::needDataByUrl,
-                mManager->tracksListener(), &TracksListener::trackByFileNameInList);
-        connect(mManager->tracksListener(), &TracksListener::trackHasChanged,
-                this, &TrackMetadataModel::trackData);
     } else if (trackDatabase) {
         mDataLoader.setDatabase(trackDatabase);
     }
@@ -496,13 +498,11 @@ void TrackMetadataModel::fillDataForNewRadio()
     mTrackData.clear();
     mTrackKeys.clear();
 
-    for (auto role : {
-         DataTypes::TitleRole,
-         DataTypes::ResourceRole,
-         DataTypes::CommentRole,
-         DataTypes::DatabaseIdRole
+    auto allRoles = {DataTypes::TitleRole, DataTypes::ResourceRole,
+                     DataTypes::CommentRole, DataTypes::ImageUrlRole,
+                     DataTypes::DatabaseIdRole};
 
-}) {
+    for (auto role : allRoles) {
         mTrackKeys.push_back(role);
         if (role == DataTypes::DatabaseIdRole) {
             mTrackData[role] = -1;
@@ -537,11 +537,6 @@ void TrackMetadataModel::setDatabase(DatabaseInterface *trackDatabase)
     initialize(nullptr, trackDatabase);
 }
 
-void TrackMetadataModel::saveData()
-{
-    Q_EMIT saveRadioData(mTrackData);
-}
-
 void TrackMetadataModel::deleteRadio()
 {
     if (mTrackData[DataTypes::DatabaseIdRole]>=0) {
@@ -557,7 +552,8 @@ void TrackMetadataModel::radioData(const TrackDataType &radiosData)
     }
 
     const QList<DataTypes::ColumnsRoles> fieldsForTrack({DataTypes::TitleRole, DataTypes::ResourceRole,
-                                                                 DataTypes::CommentRole, DataTypes::DatabaseIdRole});
+                                                                 DataTypes::CommentRole, DataTypes::ImageUrlRole,
+                                                                 DataTypes::DatabaseIdRole});
 
     fillDataFromTrackData(radiosData, fieldsForTrack);
 }
