@@ -68,6 +68,7 @@ public:
     enum ItemType
     {
         TextEntry,
+        UrlEntry,
         IntegerEntry,
         RatingEntry,
         DateEntry,
@@ -135,8 +136,6 @@ public Q_SLOTS:
 
     void setDatabase(DatabaseInterface *trackDatabase);
 
-    void saveData();
-
     void deleteRadio();
 
     void radioData(const TrackMetadataModel::TrackDataType &radiosData);
@@ -156,6 +155,8 @@ protected:
 
     virtual void fillLyricsDataFromTrack();
 
+    const TrackDataType& allTrackData() const;
+
 private Q_SLOTS:
 
     void lyricsValueIsReady();
