@@ -22,7 +22,7 @@
 #include "mediaplayer2player.h"
 #include "mpris2.h"
 
-#include "mediaplaylist.h"
+#include "mediaplaylistproxymodel.h"
 #include "manageaudioplayer.h"
 #include "managemediaplayercontrol.h"
 #include "manageheaderbar.h"
@@ -30,22 +30,22 @@
 
 #include <QCryptographicHash>
 #include <QStringList>
-#include <QMetaClassInfo>
 #include <QDBusMessage>
 #include <QDBusConnection>
 
-#include <QDebug>
 
 static const double MAX_RATE = 1.0;
 static const double MIN_RATE = 1.0;
 
-MediaPlayer2Player::MediaPlayer2Player(MediaPlayList *playListControler, ManageAudioPlayer *manageAudioPlayer,
-                                       ManageMediaPlayerControl *manageMediaPlayerControl, ManageHeaderBar *manageHeaderBar, AudioWrapper *audioPlayer, QObject* parent)
+MediaPlayer2Player::MediaPlayer2Player(MediaPlayListProxyModel *playListControler, ManageAudioPlayer *manageAudioPlayer,
+                                       ManageMediaPlayerControl *manageMediaPlayerControl, ManageHeaderBar *manageHeaderBar,
+                                       AudioWrapper *audioPlayer, bool showProgressOnTaskBar, QObject* parent)
     : QDBusAbstractAdaptor(parent), m_playListControler(playListControler), m_manageAudioPlayer(manageAudioPlayer),
       m_manageMediaPlayerControl(manageMediaPlayerControl), m_manageHeaderBar(manageHeaderBar), m_audioPlayer(audioPlayer),
       mProgressIndicatorSignal(QDBusMessage::createSignal(QStringLiteral("/org/kde/elisa"),
                                                           QStringLiteral("com.canonical.Unity.LauncherEntry"),
-                                                          QStringLiteral("Update")))
+                                                          QStringLiteral("Update"))),
+      mShowProgressOnTaskBar(showProgressOnTaskBar)
 {
     if (!m_playListControler) {
         return;
@@ -97,20 +97,22 @@ QString MediaPlayer2Player::PlaybackStatus() const
         result = QStringLiteral("Paused");
     }
 
-    QVariantMap parameters;
+    if (mShowProgressOnTaskBar) {
+        QVariantMap parameters;
 
-    if (m_manageAudioPlayer->playerPlaybackState() == QMediaPlayer::StoppedState || m_audioPlayer->duration() == 0) {
-        parameters.insert(QStringLiteral("progress-visible"), false);
-        parameters.insert(QStringLiteral("progress"), 0);
-    } else {
-        parameters.insert(QStringLiteral("progress-visible"), true);
-        parameters.insert(QStringLiteral("progress"), qRound(static_cast<double>(m_position / m_audioPlayer->duration())) / 1000.0);
+        if (m_manageAudioPlayer->playerPlaybackState() == QMediaPlayer::StoppedState || m_audioPlayer->duration() == 0) {
+            parameters.insert(QStringLiteral("progress-visible"), false);
+            parameters.insert(QStringLiteral("progress"), 0);
+        } else {
+            parameters.insert(QStringLiteral("progress-visible"), true);
+            parameters.insert(QStringLiteral("progress"), qRound(static_cast<double>(m_position / m_audioPlayer->duration())) / 1000.0);
+        }
+
+        mProgressIndicatorSignal.setArguments({QStringLiteral("application://org.kde.elisa.desktop"), parameters});
+
+        QDBusConnection::sessionBus().send(mProgressIndicatorSignal);
     }
 
-    mProgressIndicatorSignal.setArguments({QStringLiteral("application://org.kde.elisa.desktop"), parameters});
-
-    QDBusConnection::sessionBus().send(mProgressIndicatorSignal);
-
     return result;
 }
 
@@ -215,13 +217,21 @@ void MediaPlayer2Player::setPropertyPosition(int newPositionInMs)
 
     Q_EMIT Seeked(m_position);
 
-    QVariantMap parameters;
-    parameters.insert(QStringLiteral("progress-visible"), true);
-    parameters.insert(QStringLiteral("progress"), static_cast<double>(newPositionInMs) / m_audioPlayer->duration());
+    /* only sent new progress when it has advanced more than 1 %
+     * to limit DBus traffic
+     */
+    const auto incrementalProgress = static_cast<double>(newPositionInMs - mPreviousProgressPosition) / m_audioPlayer->duration();
+    if (mShowProgressOnTaskBar && (incrementalProgress > 0.01 || incrementalProgress < 0))
+    {
+        mPreviousProgressPosition = newPositionInMs;
+        QVariantMap parameters;
+        parameters.insert(QStringLiteral("progress-visible"), true);
+        parameters.insert(QStringLiteral("progress"), static_cast<double>(newPositionInMs) / m_audioPlayer->duration());
 
-    mProgressIndicatorSignal.setArguments({QStringLiteral("application://org.kde.elisa.desktop"), parameters});
+        mProgressIndicatorSignal.setArguments({QStringLiteral("application://org.kde.elisa.desktop"), parameters});
 
-    QDBusConnection::sessionBus().send(mProgressIndicatorSignal);
+        QDBusConnection::sessionBus().send(mProgressIndicatorSignal);
+    }
 }
 
 double MediaPlayer2Player::Rate() const
@@ -414,6 +424,30 @@ int MediaPlayer2Player::mediaPlayerPresent() const
     return m_mediaPlayerPresent;
 }
 
+bool MediaPlayer2Player::showProgressOnTaskBar() const
+{
+    return mShowProgressOnTaskBar;
+}
+
+void MediaPlayer2Player::setShowProgressOnTaskBar(bool value)
+{
+    mShowProgressOnTaskBar = value;
+
+    QVariantMap parameters;
+
+    if (!mShowProgressOnTaskBar || m_manageAudioPlayer->playerPlaybackState() == QMediaPlayer::StoppedState || m_audioPlayer->duration() == 0) {
+        parameters.insert(QStringLiteral("progress-visible"), false);
+        parameters.insert(QStringLiteral("progress"), 0);
+    } else {
+        parameters.insert(QStringLiteral("progress-visible"), true);
+        parameters.insert(QStringLiteral("progress"), qRound(static_cast<double>(m_position / m_audioPlayer->duration())) / 1000.0);
+    }
+
+    mProgressIndicatorSignal.setArguments({QStringLiteral("application://org.kde.elisa.desktop"), parameters});
+
+    QDBusConnection::sessionBus().send(mProgressIndicatorSignal);
+}
+
 void MediaPlayer2Player::setMediaPlayerPresent(int status)
 {
     if (m_mediaPlayerPresent != status) {
@@ -437,7 +471,7 @@ void MediaPlayer2Player::signalPropertiesChange(const QString &property, const Q
     properties[property] = value;
     const int ifaceIndex = metaObject()->indexOfClassInfo("D-Bus Interface");
     QDBusMessage msg = QDBusMessage::createSignal(QStringLiteral("/org/mpris/MediaPlayer2"),
-        QStringLiteral("org.freedesktop.DBus.Properties"), QStringLiteral("PropertiesChanged"));
+                                                  QStringLiteral("org.freedesktop.DBus.Properties"), QStringLiteral("PropertiesChanged"));
 
     msg << QLatin1String(metaObject()->classInfo(ifaceIndex).value());
     msg << properties;
